.. :changelog:

History
-------

0.1.1 (2017-04-11)
++++++++++++++++++

- Add the possibility to configure the current version detector


0.1.0 (2017-03-28)
++++++++++++++++++

- First release on PyPI.
